==> unixodbc_2.2.14p2.orig.tar.gz: unixODBC-2.2.14-p2/Drivers/template/SQLForeignKeys.c <==
/********************************************************************
 * SQLForeignKeys
 *
 **********************************************************************
 *
 * This code was created by Peter Harvey (mostly during Christmas 98/99).
 * This code is LGPL. Please ensure that this message remains in future
 * distributions and uses of this code (thats about all I get out of it).
 * - Peter Harvey pharvey@codebydesign.com
 *
 ********************************************************************/

#include "driver.h"

SQLRETURN SQLForeignKeys( SQLHSTMT        hDrvStmt,
                                SQLCHAR         *szPKCatalogName,
                                SQLSMALLINT     nPKCatalogNameLength,
                                SQLCHAR         *szPKSchemaName,
                                SQLSMALLINT     nPKSchemaNameLength,
                                SQLCHAR         *szPKTableName,
                                SQLSMALLINT     nPKTableNameLength,
                                SQLCHAR         *szFKCatalogName,
                                SQLSMALLINT     nFKCatalogNameLength,
                                SQLCHAR         *szFKSchemaName,
                                SQLSMALLINT     nFKSchemaNameLength,
                                SQLCHAR         *szFKTableName,
                                SQLSMALLINT     nFKTableNameLength )
{
    HDRVSTMT hStmt	= (HDRVSTMT)hDrvStmt;

	/* SANITY CHECKS */
    if( NULL == hStmt )
        return SQL_INVALID_HANDLE;

	sprintf((char*) hStmt->szSqlMsg, "hStmt = $%08lX", hStmt );
    logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING,(char*) hStmt->szSqlMsg );

    /************************
     * REPLACE THIS COMMENT WITH SOMETHING USEFULL
     ************************/
    logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, "SQL_ERROR This function not supported" );


    return SQL_ERROR;
}

==> unixodbc_2.3.14.orig.tar.gz: unixODBC-2.3.14/Drivers/template/SQLForeignKeys.c <==
/********************************************************************
 * SQLForeignKeys
 *
 **********************************************************************
 *
 * This code was created by Peter Harvey (mostly during Christmas 98/99).
 * This code is LGPL. Please ensure that this message remains in future
 * distributions and uses of this code (thats about all I get out of it).
 * - Peter Harvey pharvey@codebydesign.com
 *
 ********************************************************************/

#include <config.h>
#include "driver.h"

SQLRETURN SQLForeignKeys( SQLHSTMT        hDrvStmt,
                                SQLCHAR         *szPKCatalogName,
                                SQLSMALLINT     nPKCatalogNameLength,
                                SQLCHAR         *szPKSchemaName,
                                SQLSMALLINT     nPKSchemaNameLength,
                                SQLCHAR         *szPKTableName,
                                SQLSMALLINT     nPKTableNameLength,
                                SQLCHAR         *szFKCatalogName,
                                SQLSMALLINT     nFKCatalogNameLength,
                                SQLCHAR         *szFKSchemaName,
                                SQLSMALLINT     nFKSchemaNameLength,
                                SQLCHAR         *szFKTableName,
                                SQLSMALLINT     nFKTableNameLength )
{
    HDRVSTMT hStmt	= (HDRVSTMT)hDrvStmt;

	/* SANITY CHECKS */
    if( NULL == hStmt )
        return SQL_INVALID_HANDLE;

	sprintf((char*) hStmt->szSqlMsg, "hStmt = $%08lX", (long)hStmt );
    logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING,(char*) hStmt->szSqlMsg );

    /************************
     * REPLACE THIS COMMENT WITH SOMETHING USEFULL
     ************************/
    logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, "SQL_ERROR This function not supported" );


    return SQL_ERROR;
}
